import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { ConfigService } from '../../../services/config.service';
import { AdminRoutes } from '../../admin-routing.module';

@Component({
  selector: 'app-admin-header',
  templateUrl: './admin-header.component.html',
  styleUrls: ['./admin-header.component.scss'],
})
export class AdminHeaderComponent implements OnInit {
  private ghostLink: string;
  public currentTab = 0;
  public routes = AdminRoutes;

  public tabs = [
    { label: 'Revendication structure', route: this.routes.pendingStructures.link },
    { label: 'Liste structures', route: this.routes.structuresList.link },
    { label: 'Structures supprimées', route: this.routes.deletedStructures.link },
    { label: 'Gestion des utilisateurs', route: this.routes.manageUsers.link },
    { label: 'Fonctions', route: this.routes.jobsList.link },
    { label: 'Employeurs', route: this.routes.employersList.link },
    { label: 'CNFS Espace Coop', route: this.routes.espaceCoopCNFS.link },
  ];

  constructor(
    public router: Router,
    private configService: ConfigService,
  ) {}

  ngOnInit(): void {
    // Fetch configuration and set ghost link
    this.configService.getConfig().then((config) => {
      this.ghostLink = config.ghostAdminUrl;
    });

    // We navigateTo distinct routes, so we need to recover the currentTab after rerouting
    this.currentTab = this.tabs.findIndex((tab) => tab.route === this.router.url.substring(1));
  }

  public getTabsNames(): string[] {
    return this.tabs.map((tab) => tab.label);
  }

  public navigateTo(tabIndex: number): void {
    this.router.navigateByUrl(this.tabs[tabIndex].route);
  }

  public openGhost(): void {
    window.open(this.ghostLink);
  }
}
