import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { UserAnnuary } from '../models/user.model';
import { AuthService } from '../services/auth.service';
import { SearchService } from '../structure-list/services/search.service';
import { SearchQuery } from './models/searchQuery.model';

@Component({
  selector: 'app-annuaire',
  templateUrl: './annuaire.component.html',
  styleUrls: ['./annuaire.component.scss'],
})
export class AnnuaireComponent implements OnInit {
  constructor(
    public searchService: SearchService,
    private authService: AuthService,
    private route: ActivatedRoute,
  ) {}

  public userList: UserAnnuary[] = [];
  public totalUserResult: number;
  public resetFilters = 0;
  public isLoading = true;
  private isAlreadySearching = false;

  ngOnInit(): void {
    this.route.queryParams.subscribe((params) => {
      const searchQuery: SearchQuery = {
        search: params['search'] || '',
        page: Number(params['page']) || 1,
        jobFilters: params['jobs'] ? params['jobs'].split('|') : [],
        employerFilters: params['employers'] ? params['employers'].split('|') : [],
      };
      this.searchUsers(searchQuery);
    });

    if (this.userIsLoggedIn()) {
      this.userList = this.searchService.previousResult$.getValue().docs;
      this.totalUserResult = this.searchService.previousResult$.getValue().count;
      if (this.userList.length !== 0) {
        this.isLoading = false;
      }
    } else {
      this.searchService.getUserRegistryCount().subscribe((count) => {
        this.totalUserResult = count;
        this.isLoading = false;
      });
    }
  }

  public userIsLoggedIn(): boolean {
    return this.authService.isLoggedIn();
  }

  private loadParams(params: SearchQuery): void {
    this.searchService.annuaireSearchQuery = params;
  }

  public searchUsers(params: SearchQuery): void {
    if (!this.isAlreadySearching) {
      this.isAlreadySearching = true;
      params.page = params.page || 1;
      if (params.page === 1) {
        this.userList = [];
      }
      this.loadParams(params);
      this.isLoading = true;
      this.searchService
        .searchUserRegistry(params.search, params.page, params.jobFilters, params.employerFilters)
        .then((res) => {
          // We only push new users instead of reassigning userList to avoid an unwanted scroll
          this.userList.push(...res.docs);
          this.searchService.previousResult$.next({ count: res.count, docs: this.userList });
          this.totalUserResult = res.count;
          this.isLoading = false;
          this.isAlreadySearching = false;
        });
    }
  }

  public shouldResetFilters(): void {
    this.resetFilters++;
  }

  public showMore(): void {
    if (this.searchService.annuaireSearchQuery) {
      this.searchService.annuaireSearchQuery.page++;
      this.searchUsers(this.searchService.annuaireSearchQuery);
    }
  }
}
