import {
  AfterViewInit,
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnChanges,
  Output,
  SimpleChanges,
} from '@angular/core';
import { Router } from '@angular/router';
import { UserAnnuary } from '../../models/user.model';
import { WindowScrollService } from '../../shared/service/windowScroll.service';

@Component({
  selector: 'app-result-list',
  templateUrl: './result-list.component.html',
  styleUrls: ['./result-list.component.scss'],
})
export class ResultListComponent implements OnChanges, AfterViewInit {
  constructor(
    private router: Router,
    private windowScrollService: WindowScrollService,
    private elementRef: ElementRef,
  ) {}
  @Input() userList: UserAnnuary[];
  @Input() totalUserResult: number;
  @Input() isLogged: boolean;
  @Input() isLoading: boolean;
  @Output() resetEvent = new EventEmitter<void>();
  @Output() showMoreEvent = new EventEmitter<void>();
  public maxPerPage = 20;
  public showPagination = false;
  public keyboardEvent = false;
  public nextChildIndex: number;

  ngAfterViewInit(): void {
    setTimeout(() => {
      document.getElementById('app-body')?.scrollTo({ top: this.windowScrollService.scrollYToPreserve.value });
    }, 10);
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.totalUserResult?.currentValue > this.maxPerPage) {
      this.showPagination = true;
    }
    if (this.userList.length >= this.totalUserResult) this.showPagination = false;

    // Accessibility: after click on "view more" button, send focus to the first newly displayed member card
    if (this.keyboardEvent && this.nextChildIndex) {
      setTimeout(() => {
        this.setFocusOnFirstNewMemberCard();
      }, 0);
    }
  }

  public goLogin(): void {
    this.router.navigate(['/connexion'], { queryParams: { returnUrl: '/annuaire' } });
  }

  public goRegister(): void {
    this.router.navigateByUrl('/formulaire/compte');
  }

  public resetFilters(): void {
    this.resetEvent.emit();
  }

  public onMemberCardKeydown(event: KeyboardEvent): void {
    switch (event.key) {
      case 'ArrowUp':
      case 'ArrowDown':
      case 'Tab':
        this.keyboardEvent = true;
        break;
    }
  }

  private setFocusOnFirstNewMemberCard(): void {
    const lastFocusedMemberCard = this.elementRef.nativeElement.querySelector(
      `.users app-member-card:nth-child(${this.nextChildIndex}) > div`,
    );
    if (lastFocusedMemberCard) {
      const focusedElement = lastFocusedMemberCard as HTMLElement;
      focusedElement.focus();
    }
  }

  public showMore(): void {
    this.nextChildIndex = this.userList.length + 1;
    this.showMoreEvent.emit();
  }
}
