import { Component, EventEmitter, Input, Output } from '@angular/core';
import { AbstractControl, UntypedFormGroup } from '@angular/forms';
import { User } from '../../../../models/user.model';
import { CustomRegExp } from '../../../../utils/CustomRegExp';

@Component({
  selector: 'app-account-credentials',
  templateUrl: './account-credentials.component.html',
  styleUrls: ['./account-credentials.component.scss'],
})
export class AccountCredentialsComponent {
  @Input() accountForm: UntypedFormGroup;
  @Input() isAccountMode: boolean;
  @Input() profile: User;
  @Output() validateForm = new EventEmitter<any>();
  @Output() userExists = new EventEmitter<any>();

  public checkIfPasswordHasSpecialChar(password: string): boolean {
    if (password.match(CustomRegExp.SPECHAR)) return true;
    return false;
  }

  public checkIfPasswordHasDigit(password: string): boolean {
    if (password.match(CustomRegExp.DIGIT)) return true;
    return false;
  }

  public checkIfPasswordHasUpperCase(password: string): boolean {
    if (password.match(CustomRegExp.UPPERCASE)) return true;
    return false;
  }

  public checkIfPasswordHasLowerCase(password: string): boolean {
    if (password.match(CustomRegExp.LOWERCASE)) return true;
    return false;
  }
  public setValidationsForm(): void {
    this.validateForm.emit();
  }

  /** Type guard function to check if the input is an EventTarget */
  private isEventTarget(target: EventTarget | string): target is EventTarget {
    return typeof target !== 'string';
  }

  public verifyUserExist(target: EventTarget | string): void {
    const value = this.isEventTarget(target) ? (target as HTMLInputElement).value : target;
    this.userExists.emit(value);
  }

  public getStatus(control: AbstractControl): 'error' | 'success' | null {
    if (!control.value) {
      return null;
    }
    if (control.invalid) {
      return 'error';
    } else {
      return 'success';
    }
  }
}
