import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';

import { User } from '../../../models/user.model';
import { ProfileService } from '../../../profile/services/profile.service';
import { stepType } from '../../step.type';
import { formType } from '../formType.enum';
import { accountFormStep } from './accountFormStep.enum';

@Component({
  selector: 'app-account-form',
  templateUrl: './account-form.component.html',
})
export class AccountFormComponent implements OnInit, OnChanges {
  @Input() nbSteps: number;
  @Input() currentStep: stepType;
  @Input() accountForm: UntypedFormGroup;
  @Input() isAccountMode: boolean;
  @Output() pageValid = new EventEmitter<boolean>();
  @Output() acceptNewsletter = new EventEmitter<boolean>();

  public pagesValidation = [];
  public profile: User;
  public accountFormStepEnum = accountFormStep;
  public formType = formType;

  constructor(private profileService: ProfileService) {}

  ngOnInit(): void {
    this.setValidationsForm();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.currentStep && this.pagesValidation.length > 0) {
      this.updatePageValid();
    }
  }

  public setValidationsForm(): void {
    this.pagesValidation[accountFormStep.accountInfo] = {
      valid:
        this.accountForm.get('surname').valid &&
        this.accountForm.get('name').valid &&
        this.accountForm.get('phone').valid,
    };
    this.pagesValidation[accountFormStep.accountCredentials] = {
      valid:
        this.accountForm.get('email').valid &&
        this.accountForm.get('password').valid &&
        this.accountForm.get('confirmPassword').valid,
    };
    this.pagesValidation[accountFormStep.accountNewsletter] = {
      valid: this.accountForm.get('hasAcceptedNewsletter').value !== null,
    };
    this.pagesValidation[accountFormStep.confirmEmailSentInfo] = {
      valid: true,
    };

    this.updatePageValid();
  }

  public verifyUserExist(inputEmail): void {
    if (this.accountForm.get('email').valid) {
      this.profileService.isEmailAlreadyUsed(inputEmail).subscribe((isExist) => {
        if (isExist) {
          this.accountForm.get('email').setErrors({ alreadyExist: true });
          this.setValidationsForm();
        }
      });
    }
  }

  private updatePageValid(): void {
    const isPageValid = this.pagesValidation[this.currentStep].valid;
    this.pageValid.emit(isPageValid);
  }
}
