import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { AuthGuard } from '../../guards/auth.guard';
import { DeactivateGuard } from '../../guards/deactivate.guard';
import { RoleGuard } from '../../guards/role.guard';
import { StructureResolver } from '../../resolvers/structure.resolver';
import { TempUserResolver } from '../../resolvers/temp-user.resolver';
import { RouteRole } from '../../shared/enum/routeRole.enum';
import { AccountFormComponent } from './account-form/account-form.component';
import { FormViewComponent } from './form-view.component';
import { PersonalOfferGuard } from './guards/personalOffer.guard';
import { PersonalOfferFormComponent } from './personal-offer-form/personal-offer-form.component';
import { ProfileFormComponent } from './profile-form/profile-form.component';
import { StructureFormComponent } from './structure-form/structure-form.component';

const routes: Routes = [
  {
    path: 'structure/:permalink/:step',
    component: FormViewComponent,
    canActivate: [RoleGuard],
    data: { allowedRoles: [RouteRole.structureAdmin] },
    resolve: {
      structure: StructureResolver,
    },
  },
  {
    path: 'inscription/:id',
    component: FormViewComponent,
    canDeactivate: [DeactivateGuard],
    resolve: {
      user: TempUserResolver,
    },
  },
  {
    path: '',
    component: FormViewComponent,
    canDeactivate: [DeactivateGuard],
    children: [
      {
        path: 'structure',
        canActivate: [AuthGuard],
        component: StructureFormComponent,
      },
      {
        path: 'profil',
        canActivate: [AuthGuard],
        component: ProfileFormComponent,
      },
      {
        path: 'offre-personnelle',
        canActivate: [AuthGuard, PersonalOfferGuard],
        component: PersonalOfferFormComponent,
      },
      {
        path: 'compte',
        component: AccountFormComponent,
      },
      {
        path: '**',
        redirectTo: 'compte',
      },
    ],
  },
];
@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class FormViewRoutingModule {}
