import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Router } from '@angular/router';
import { CategoriesToggle } from 'src/app/models/categoriesToggle.model';
import { CategoryEnum } from 'src/app/shared/enum/category.enum';
import { Category } from 'src/app/structure-list/models/category.model';
import { SearchService } from 'src/app/structure-list/services/search.service';
import { stepType } from '../../step.type';
import { formType } from '../formType.enum';
import { personalOfferFormStep } from './personalOfferFormStep.enum';

@Component({
  selector: 'app-personal-offer-form',
  templateUrl: './personal-offer-form.component.html',
})
export class PersonalOfferFormComponent implements OnChanges, OnInit {
  @Input() nbSteps: number;
  @Input() currentStep: stepType;
  @Input() personalOfferForm: UntypedFormGroup;
  @Input() structureName: string;
  @Output() setHasOtherOffer = new EventEmitter<boolean>();
  @Output() pageValid = new EventEmitter<any>();

  public trainingCategories: CategoriesToggle[] = [];
  public onlineProcedures: Category;
  public personalOfferFormStep = personalOfferFormStep;
  public formTypeEnum = formType;

  constructor(
    private searchService: SearchService,
    private router: Router,
  ) {}

  ngOnInit(): void {
    this.setCategories();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.currentStep) {
      if (
        this.currentStep === personalOfferFormStep.personalOfferAccompaniment ||
        this.currentStep === personalOfferFormStep.personalOfferTrainingType
      ) {
        this.pageValid.emit();
      }
    }
  }

  async setCategories(): Promise<void> {
    const categories = await this.searchService.getCategories().toPromise();
    categories.forEach((categ) => {
      switch (categ.id) {
        case CategoryEnum.onlineProcedures: {
          // We sort modules alphabetically, except for the 'autres' module which is always at the end
          this.onlineProcedures = categ;
          const othersModule = this.onlineProcedures.modules.find((module) => module.id === 'autres');
          const sortedModules = this.onlineProcedures.modules.filter((module) => module.id !== 'autres').sort((a, b) => a.name.localeCompare(b.name));
          if (othersModule) sortedModules.push(othersModule);
          this.onlineProcedures.modules = sortedModules;
          break;
        }
        case CategoryEnum.baseSkills:
        case CategoryEnum.advancedSkills: {
          this.trainingCategories.push({ category: categ, openned: false });
          break;
        }
      }
    });
  }

  public validPage(): void {
    this.pageValid.emit();
  }

  public setOtherOffer(flag: boolean): void {
    this.setHasOtherOffer.emit(flag);
  }

  public goToProfile(): void {
    this.router.navigateByUrl('/profil');
  }
}
