import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Employer } from '../../../../models/employer.model';
import { ProfileService } from '../../../../profile/services/profile.service';

@Component({
  selector: 'app-profile-employer-selection',
  templateUrl: './profile-employer-selection.component.html',
})
export class ProfileEmployerSelectionComponent implements OnInit {
  @Input() profileForm: UntypedFormGroup;
  @Output() validateForm = new EventEmitter<Employer>();

  public employerName: string;

  constructor(public profileService: ProfileService) {}

  ngOnInit(): void {
    this.employerName = this.profileForm.get('employer').value.name;
  }

  public onCreateValueChange(searchString: string): void {
    this.profileForm.get('employer').patchValue({
      name: searchString,
      validated: false,
    });
    this.validateForm.emit();
  }

  public selectedResult(employer: Employer): void {
    this.profileForm.get('employer').patchValue({
      name: employer?.name,
      validated: employer?.validated,
    });
    this.employerName = employer?.name;
    this.validateForm.emit();
  }

  public onValueChange(): void {
    // If the user changes the value in the autocomplete input, set an empty employer to invalidate the form
    this.profileForm.get('employer').patchValue({
      name: '',
      validated: false,
    });
    this.validateForm.emit();
  }
}
