import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { stepType } from '../../step.type';
import { formType } from '../formType.enum';
import { profileFormStep } from './profileFormStep.enum';

@Component({
  selector: 'app-profile-form',
  templateUrl: './profile-form.component.html',
})
export class ProfileFormComponent implements OnInit, OnChanges {
  @Input() profileForm: UntypedFormGroup;
  @Input() nbSteps: number;
  @Input() currentStep: stepType;
  @Output() pageValid = new EventEmitter<any>();
  @Output() goNext = new EventEmitter<any>();

  public isPageValid: boolean;
  public profileFormStepEnum = profileFormStep;
  public pagesValidation = [];
  public formTypeEnum = formType;

  ngOnInit(): void {
    this.setValidationsForm();
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.currentStep && this.pagesValidation.length > 0) {
      this.updatePageValid();
    }
  }

  public setValidationsForm(): void {
    this.pagesValidation[profileFormStep.profileBeginningInfo] = {
      valid: true,
    };
    this.pagesValidation[profileFormStep.profileEmployerSelection] = {
      valid: this.profileForm.get('employer').valid,
    };
    this.pagesValidation[profileFormStep.profileJobSelection] = {
      valid:
        (this.profileForm.get('job').get('name').valid && !this.profileForm.get('job').value.hasPersonalOffer) ||
        (this.profileForm.get('job').get('name').valid &&
          this.profileForm.get('job').value.hasPersonalOffer === true &&
          this.profileForm.get('withAppointment').valid),
    };

    this.updatePageValid();
  }

  /**
   * Update valid page or return page validity of the given index
   */
  public updatePageValid(): void {
    this.isPageValid = this.pagesValidation[this.currentStep].valid;
    this.pageValid.emit(this.isPageValid);
  }
}
