import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Job } from '../../../../models/job.model';
import { ProfileService } from '../../../../profile/services/profile.service';

@Component({
  selector: 'app-profile-job-selection',
  templateUrl: './profile-job-selection.component.html',
})
export class ProfileJobSelectionComponent implements OnInit {
  @Input() profileForm: UntypedFormGroup;
  @Output() validateForm = new EventEmitter<Job>();

  public jobName: string;
  public selectedJob: Job;
  public selectedRdvChoice: boolean;
  public hasPersonalOffer = false;

  constructor(public profileService: ProfileService) {}

  ngOnInit(): void {
    this.jobName = this.profileForm.get('job').value.name;
  }

  public onCreateValueChange(searchString: string): void {
    this.profileForm.get('job').patchValue({
      name: searchString,
      validated: false,
    });
    this.validateForm.emit();
  }

  public selectedResult(job: Job): void {
    this.profileForm.get('job').patchValue({
      name: job?.name,
      validated: job?.validated,
      hasPersonalOffer: job?.hasPersonalOffer,
    });
    this.jobName = job?.name;
    this.hasPersonalOffer = job?.hasPersonalOffer;
    this.validateForm.emit();
  }

  public onValueChange(): void {
    // If the user changes the value in the autocomplete input, set an empty job to invalidate the form
    this.profileForm.get('job').patchValue({
      name: '',
      validated: false,
    });
    this.validateForm.emit();
  }

  public onRdvRadioChange(value: boolean): void {
    this.selectedRdvChoice = value;
    this.profileForm.get('withAppointment').setValue(this.selectedRdvChoice);
    this.validateForm.emit();
  }
}
