import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { PendingStructureLink } from '../../../../models/pendingStructure.model';
import { Structure } from '../../../../models/structure.model';
import { ProfileService } from '../../../../profile/services/profile.service';
import { StructureService } from '../../../../services/structure.service';
import { Filter } from '../../../../structure-list/models/filter.model';

@Component({
  selector: 'app-profile-structure-choice',
  templateUrl: './profile-structure-choice.component.html',
  styleUrls: ['./profile-structure-choice.component.scss'],
})
export class ProfileStructureChoiceComponent implements OnInit {
  @Input() structureForm: UntypedFormGroup;
  @Output() validateForm = new EventEmitter<Structure>();
  @Output() selectedStructure: EventEmitter<Structure> = new EventEmitter<Structure>();
  @Output() createStructure = new EventEmitter<string>();
  public searchString = '';
  public structures: Structure[];
  public selectedStructureItem: Structure;
  public isAlreadySearching = false;
  public profileStructuresLink: string[] = [];
  public profilePendingStructureLink: PendingStructureLink[] = [];
  public itemSelected: string = null;

  constructor(
    private structureService: StructureService,
    private profileService: ProfileService,
  ) {}

  ngOnInit(): void {
    this.isAlreadySearching = true;
    this.profileService.getProfile().then((profile) => {
      this.isAlreadySearching = false;
      this.profileStructuresLink = [...profile.structuresLink];
      this.profilePendingStructureLink = [...profile.pendingStructuresLink];
      this.getStructures(null);
    });
    this.validateForm.emit();
  }

  public onSearchChange(searchString: string): void {
    const filters: Filter[] = [];
    if (searchString.length > 0) {
      filters.push(new Filter('query', searchString));
    }
    this.getStructures(filters);
  }

  public selectedResult(structure: Structure): void {
    if (structure.alreadySelected) {
      return;
    }
    this.itemSelected = this.itemSelected === structure._id ? null : structure._id;
    if (this.itemSelected) {
      this.selectedStructureItem = structure;
      this.structureForm.patchValue({ _id: structure._id, structureName: structure.structureName });
      this.validateForm.emit();
    } else {
      this.selectedStructureItem = null;
      this.structureForm.patchValue({ _id: null, structureName: null });
      this.validateForm.emit();
    }
  }

  public isSelectedStructure(structure: Structure): boolean {
    if (this.selectedStructureItem && this.selectedStructureItem._id === structure._id) {
      return true;
    } else {
      return false;
    }
  }

  private getStructures(filters: Filter[]): void {
    if (!this.isAlreadySearching) {
      this.isAlreadySearching = true;
      this.structureService.getStructuresByName(filters).subscribe((structures) => {
        structures.forEach((structure) => {
          if (
            this.profileStructuresLink.includes(structure._id) ||
            this.profilePendingStructureLink.map((pending) => pending.id).includes(structure._id)
          ) {
            structure.alreadySelected = true;
          }
        });

        this.structures = this.sortStructures(structures);
        this.isAlreadySearching = false;
      });
    }
  }

  private sortStructures(structures: Structure[]): Structure[] {
    if (this.searchString === '') structures.sort((a, b) => a.structureName.localeCompare(b.structureName));
    structures.sort((a, b) => Number(b.alreadySelected) - Number(a.alreadySelected));
    return structures;
  }

  public addStructure(): void {
    this.createStructure.emit(this.searchString);
  }
}
