import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Utils } from '../../../../utils/utils';

@Component({
  selector: 'app-structure-contact',
  templateUrl: './structure-contact.component.html',
})
export class StructureContactComponent implements OnInit {
  @Input() structureForm: UntypedFormGroup;
  @Input() isEditMode: boolean;
  @Output() validateForm = new EventEmitter<any>();

  constructor(public utils: Utils) {}

  ngOnInit(): void {
    this.validateForm.emit();
  }

  public setValidationsForm(): void {
    this.validateForm.emit();
  }

  public isRequirePhoneOrMailNotValid(): boolean {
    return this.structureForm.errors?.requirePhoneOrMail ?? false;
  }

  public isContactMailValid(): boolean {
    return (
      !this.isRequirePhoneOrMailNotValid() &&
      this.structureForm.get('contactMail').valid &&
      this.structureForm.get('contactMail').value
    );
  }

  public isContactMailNotValid(): boolean {
    return (
      this.isRequirePhoneOrMailNotValid() ||
      (this.structureForm.get('contactMail').invalid && this.structureForm.get('contactMail').value !== null)
    );
  }

  public isContactPhoneValid(): boolean {
    return (
      !this.isRequirePhoneOrMailNotValid() &&
      this.structureForm.get('contactPhone').valid &&
      this.structureForm.get('contactPhone').value
    );
  }

  public isContactPhoneNotValid(): boolean {
    return (
      this.isRequirePhoneOrMailNotValid() ||
      (this.structureForm.get('contactPhone').invalid && this.structureForm.get('contactPhone').value)
    );
  }

  public getContactMailStatus(): 'error' | 'success' | null {
    if (this.isContactMailValid()) {
      return 'success';
    }
    if (this.structureForm.get('contactMail').value && this.isContactMailNotValid()) {
      return 'error';
    } else {
      return null;
    }
  }

  public getContactPhoneStatus(): 'error' | 'success' | null {
    if (this.isContactPhoneValid()) {
      return 'success';
    }
    if (this.structureForm.get('contactPhone').value && this.isContactPhoneNotValid()) {
      return 'error';
    } else {
      return null;
    }
  }

  public goBack(): void {
    history.back();
  }
}
