import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { StructureType } from '../../../../models/structureType.model';
import { StructureTypeService } from '../../../../services/structure-type.service';
import { StructureCategoryEnum } from '../../../../shared/enum/structureCategory.enum';

@Component({
  selector: 'app-structure-type',
  templateUrl: './structure-type.component.html',
})
export class StructureTypeComponent implements OnInit {
  @Input() structureForm: UntypedFormGroup;
  @Input() isEditMode: boolean;
  @Output() typeStructure = new EventEmitter<string>();
  @Output() validateForm = new EventEmitter<any>();

  public pickedTypeId = '';
  public publicTypes: StructureType[];
  public privateTypes: StructureType[];
  public privateLucrativeTypes: StructureType[];
  public structureTypeCategoryEnum = StructureCategoryEnum;

  constructor(private structureTypeService: StructureTypeService) {}

  ngOnInit(): void {
    // Defines which format is valid for the 'structureType' field of the form
    this.validateForm.emit();

    // Get the list of structure types, without the "other" one
    this.structureTypeService.getStructureTypes().subscribe((types) => {
      types = types.filter((type) => type.selectable);
      types = types.sort((a, b) => a.name.localeCompare(b.name));
      this.publicTypes = types.filter((type) => type.category === this.structureTypeCategoryEnum.public);
      this.privateTypes = types.filter((type) => type.category === this.structureTypeCategoryEnum.private);
      this.privateLucrativeTypes = types.filter(
        (type) => type.category === this.structureTypeCategoryEnum.privateLucrative,
      );
    });

    // If any, get the ID of the previously selected structure type
    this.pickedTypeId = this.structureForm.get('structureType').valid
      ? this.structureForm.get('structureType').value
      : null;
  }

  public goBack(): void {
    history.back();
  }

  public pickStructureType(structureTypeId: string): void {
    this.pickedTypeId = structureTypeId;
    this.typeStructure.emit(structureTypeId);
    this.validateForm.emit();
  }
}
