import { Component, EventEmitter, Input, Output } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { User } from '../../../models/user.model';
import { Filter } from '../../../structure-list/models/filter.model';
import { OrientationUtils } from '../../../utils/orientationUtils';
import { CommonSteps, GenericOrientationSteps, StructuresListSteps } from '../enums/orientation.enums';
import { FiltersForm } from '../interfaces/filtersForm.interface';
import { StructureOrientationForm } from '../interfaces/structureOrientationForm.interface';
import { AllOrientationSteps } from '../types/orientation.types';

@Component({
  selector: 'app-equipment-buy',
  templateUrl: './equipment-buy.component.html',
})
export class EquipmentBuyComponent {
  @Input() currentStep: AllOrientationSteps;
  @Input() genericStep: GenericOrientationSteps;
  @Input() filtersForm: FormGroup<FiltersForm>;
  @Input() orientationForm: FormGroup<StructureOrientationForm>;
  @Input() filters: Filter[] = [];
  @Input() profile: User;
  @Output() validatePage = new EventEmitter<any>();

  public orientationUtils = new OrientationUtils();
  public pagesValidation: any[] = [];

  // Enums
  public GenericOrientationSteps = GenericOrientationSteps;

  public checkValidation(): void {
    switch (this.genericStep) {
      case GenericOrientationSteps.common:
        this.orientationUtils.setValidationsEquipmentForm(
          this.pagesValidation,
          this.filtersForm,
          (isValid) => this.validatePage.emit(isValid),
          this.currentStep as CommonSteps,
        );
        break;
      case GenericOrientationSteps.accompanimentTunnel:
        this.orientationUtils.setValidationsStructuresForm(
          this.pagesValidation,
          this.orientationForm,
          (isValid) => this.validatePage.emit(isValid),
          this.currentStep as StructuresListSteps,
        );
        break;
      default:
        throw new Error('Not implemented tunnel type in OnlineDemarchFormComponent');
    }
  }
}
