import { Component, EventEmitter, Input, Output } from '@angular/core';
import { Router } from '@angular/router';
import { NeedsTypes } from '../../enums/orientation.enums';
import { AllOrientationSteps } from '../../types/orientation.types';

@Component({
  selector: 'app-navigation',
  templateUrl: './navigation.component.html',
  styleUrls: ['./navigation.component.scss'],
})
export class NavigationComponent {
  @Input() currentStep: AllOrientationSteps;
  @Input() isPageValid: boolean;
  @Input() needType: NeedsTypes;
  @Input() isPrevHidden = false;
  @Input() isNextHidden = false;
  @Input() isLastStep = false;
  @Input() failedOrientation = false;

  @Output() goNext = new EventEmitter<boolean>();
  @Output() goPrev = new EventEmitter<void>();
  @Output() goReset = new EventEmitter<void>();

  public NeedsTypeEnum = NeedsTypes;

  constructor(private router: Router) {}

  public showPrevButton(): boolean {
    return this.currentStep !== null && !(this.isPrevHidden || this.isLastStep);
  }
  public showNextButton(): boolean {
    return !this.isNextHidden;
  }

  public nextPage(isPrint?: boolean): void {
    this.goNext.emit(isPrint);
  }
  public prevPage(): void {
    this.goPrev.emit();
  }

  public goCarto(): void {
    this.goReset.emit();
    this.router.navigateByUrl('/acteurs');
  }

  public resetOrientation(): void {
    this.goReset.emit();
  }
}
