import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { Observable, forkJoin, tap } from 'rxjs';
import { PersonalOffer } from '../../../../models/personalOffer.model';
import { OrientationService } from '../../../../services/orientation.service';
import { PersonalOfferService } from '../../../../services/personal-offer.service';
import { INeedItem } from '../../../../utils/orientationUtils';
import { NeedsTypes } from '../../enums/orientation.enums';

@Component({
  selector: 'app-needs-selection',
  templateUrl: './needs-selection.component.html',
})
export class NeedsSelectionComponent implements OnInit {
  @Input() needType: NeedsTypes;
  @Output() needTypeChange = new EventEmitter<NeedsTypes>();
  @Output() validate = new EventEmitter<any>();

  public needsList: INeedItem[] = [
    {
      title: 'Matériel et wifi en accès libre',
      hint: '(Wifi, ordinateur, imprimante, scanner…)',
      key: NeedsTypes.equipmentAccess,
      icon: 'orientationIndex0',
    },
    {
      title: 'Achat de matériel à tarif solidaire',
      hint: '(Ordinateur, smartphone, clé 4G, forfait internet…)',
      key: NeedsTypes.equipmentBuy,
      icon: 'orientationIndex1',
    },
    {
      title: 'Réaliser une démarche en ligne',
      hint: '(Démarche Caf, CPAM, France Travail…)',
      key: NeedsTypes.onlineDemarch,
      icon: 'orientationIndex2',
    },
    {
      title: 'Acquérir les compétences numériques de base',
      hint: '(Ordinateur et smartphone, mails, réseaux sociaux et bureautique...)',
      key: NeedsTypes.baseSkills,
      icon: 'orientationIndex3',
    },
  ];

  constructor(
    public orientationService: OrientationService,
    private personalOfferService: PersonalOfferService,
  ) {}

  ngOnInit(): void {
    if (this.orientationService.rdvUser || this.orientationService.rdvStructure) {
      this.needsList = this.needsList.filter(
        (item) => item.key === NeedsTypes.onlineDemarch || item.key === NeedsTypes.baseSkills,
      );
    }

    if (this.orientationService.rdvUser) {
      // Get the user personalOffers in this screen so they will be available to disable items in the next screen (cf. function rdvDisableItemsNotOffered)
      if (this.orientationService.rdvUser.personalOffers?.length) {
        const personalOffers$: Observable<any>[] = [];
        this.orientationService.rdvUser.personalOffers.forEach((personalOffer) => {
          personalOffers$.push(
            this.personalOfferService.getPersonalOffer(personalOffer).pipe(
              tap((personalOffer) => {
                this.orientationService.rdvUser.personalOffersPopulated.push(new PersonalOffer(personalOffer));
              }),
            ),
          );
        });
        forkJoin(personalOffers$).subscribe();
      }
    }
  }

  public selectNeed(event: string): void {
    this.needTypeChange.emit(event as NeedsTypes);
    this.validate.emit();
  }
}
