import { Component, Input } from '@angular/core';
import { Structure } from '../../../../models/structure.model';
import { AccessModality } from '../../../../structure-list/enum/access-modality.enum';
import { FreeWorkshop } from '../../../../structure/enums/freeWorkshop.enum';
import { Utils } from '../../../../utils/utils';

@Component({
  selector: 'app-detailled-structure-card',
  templateUrl: './detailled-structure-card.component.html',
  styleUrls: ['./detailled-structure-card.component.scss'],
})
export class DetailledStructureCardComponent {
  @Input({ required: true }) structure: Structure;
  public hasTclInfo = true;

  constructor(private utils: Utils) {}

  public showServices(structure: Structure): boolean {
    return (
      structure.categories.onlineProcedures.length > 0 ||
      structure.categories.baseSkills.length > 0 ||
      structure.categories.advancedSkills.length > 0 ||
      structure.hasEquipments()
    );
  }

  public getAccessLabel(name: string): string {
    return this.utils.getAccessLabel(name as AccessModality);
  }

  public isWorkShopFree(structure: Structure): string {
    switch (structure.categories.freeWorkShop as unknown as FreeWorkshop) {
      case FreeWorkshop.underCondition:
        return 'gratuit sous condition';
      case FreeWorkshop.yes:
        return 'gratuit';
      case FreeWorkshop.no:
        return 'payant';
      default:
        return null;
    }
  }
}
