import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Owner } from '../../../../../models/owner.model';
import { Structure } from '../../../../../models/structure.model';
import { OrientationService } from '../../../../../services/orientation.service';
import { Module } from '../../../../../structure-list/models/module.model';

@Component({
  selector: 'app-appointment-end',
  templateUrl: './appointment-end.component.html',
  styleUrls: ['./appointment-end.component.scss'],
})
export class AppointmentEndComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Input() structureRDV?: Structure;
  @Input() socialWorker?: Owner;
  @Input() selectedStructureRDV?: Structure;
  @Input() isOnlineMediation = false;
  @Output() checkValidation = new EventEmitter<any>();

  public hasStructure = false;
  public needs: Module[];

  constructor(public orientationService: OrientationService) {}

  async ngOnInit(): Promise<void> {
    this.checkValidation.emit();
    if (this.isOnlineMediation) {
      this.needs = this.form.get('filters').value;
      return;
    }
    if (this.form.get('structureRDV').value || this.structureRDV) {
      this.hasStructure = true;
    }
  }

  public getFormattedNeeds(): string {
    return this.needs.map((n) => n.displayText).join(', ');
  }
}
