import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';

export enum PreferredLanguages {
  french = 'Français',
  english = 'Anglais',
  arabic = 'Arabe',
}
interface LanguageOption {
  title: PreferredLanguages;
  key: PreferredLanguages;
}

@Component({
  selector: 'app-mediation-language-selection',
  templateUrl: './mediation-language-selection.component.html',
})
export class MediationLanguageSelectionComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Output() checkValidation = new EventEmitter<void>();
  public selected: string;
  public languages: LanguageOption[] = Object.values(PreferredLanguages).map((language) => ({
    title: language,
    key: language,
  }));

  ngOnInit(): void {
    this.selected = this.form.get('preferredLanguage').value;
    this.checkValidation.emit();
  }

  public handleSelect(event: string): void {
    this.selected = event;
    this.form.get('preferredLanguage').patchValue(event);
    this.checkValidation.emit();
  }
}
