import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { FormGroup, UntypedFormGroup } from '@angular/forms';
import { CategoryEnum } from 'src/app/shared/enum/category.enum';
import { OrientationService } from '../../../../services/orientation.service';
import { PersonalOfferService } from '../../../../services/personal-offer.service';
import { StructureService } from '../../../../services/structure.service';
import { Category } from '../../../../structure-list/models/category.model';
import { Module } from '../../../../structure-list/models/module.model';
import { SearchService } from '../../../../structure-list/services/search.service';
import { OrientationUtils } from '../../../../utils/orientationUtils';
import { SelectComponent } from '../../global-components/select/select.component';
import { FiltersForm } from '../../interfaces/filtersForm.interface';

@Component({
  selector: 'app-online-demarch',
  templateUrl: './online-demarch.component.html',
})
export class OnlineDemarchComponent extends SelectComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Input() filtersForm: FormGroup<FiltersForm>;
  @Output() checkValidation = new EventEmitter<void>();

  public orientationUtils = new OrientationUtils();
  public accompanimentType: Module[];
  public selectedModules: Module[] = [];
  public showStrangersModal = false;

  constructor(
    private searchService: SearchService,
    public structureService: StructureService,
    public orientationService: OrientationService,
    public personalOfferService: PersonalOfferService,
  ) {
    super();
  }

  ngOnInit(): void {
    this.selectedModules = this.filtersForm.get('filters').value;
    this.searchService.getCategories().subscribe(async (categories: Category[]) => {
      this.accompanimentType = categories.find((el) => el.id === CategoryEnum.onlineProcedures).modules;

      // For rdv from structure or annuaire, disable items which are not offered
      if (this.orientationService.rdvUser || this.orientationService.rdvStructure) {
        await this.orientationUtils.rdvDisableItemsNotOffered(
          this.accompanimentType,
          this.orientationService,
          'onlineProcedures',
        );
      }
    });

    this.checkValidation.emit();
  }

  public handleClick(module: Module): void {
    if (module.id === 'foreigners' && !super.isSelectedModule(module.id)) {
      this.showStrangersModal = true;
    }
    super.handleClick(module);
  }

  public handleClose(): void {
    this.showStrangersModal = false;
  }
}
