import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, Router } from '@angular/router';
import { Observable, firstValueFrom } from 'rxjs';
import { AuthService } from '../services/auth.service';

/**
 * Guard to assert that reset password token is valid, if present in URL
 */
@Injectable()
export class ResetPasswordTokenGuard {
  constructor(
    private authService: AuthService,
    private router: Router,
  ) {}

  async canActivate(route: ActivatedRouteSnapshot): Promise<Observable<boolean> | Promise<boolean> | boolean> {
    const token = route.queryParamMap.get('token');
    if (token) {
      const validToken = await firstValueFrom(this.authService.checkResetPasswordToken(token));
      if (!validToken) {
        this.router.navigate(['/connexion']);
        return false;
      }
    }
    return true;
  }
}
