import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, Router, UrlTree } from '@angular/router';
import { lastValueFrom } from 'rxjs';
import { ProfileService } from '../profile/services/profile.service';
import { AuthService } from '../services/auth.service';
import { StructureService } from '../services/structure.service';
import { RouteRole } from '../shared/enum/routeRole.enum';
/**
 * Guard to assert that a user is authorized to access route.
 * Admin can access everything
 */
@Injectable()
export class RoleGuard {
  constructor(
    private router: Router,
    private profileService: ProfileService,
    private authService: AuthService,
    private structureService: StructureService,
  ) {}

  async canActivate(route: ActivatedRouteSnapshot): Promise<UrlTree | boolean> {
    const allowedRoles = route.data.allowedRoles;

    if (this.authService.isLoggedIn()) {
      if (this.profileService.isAdmin()) return true;
      if (allowedRoles.includes(RouteRole.structureAdmin)) {
        const structurePermalink = route.params.permalink;
        const structure = await lastValueFrom(this.structureService.getStructureByPermalink(structurePermalink));
        if (await this.profileService.isLinkedToStructure(structure._id)) {
          return true;
        }
      }
      return this.router.parseUrl('/home');
    }
    return this.router.parseUrl('/home');
  }
}
