type dayType = 'monday' | 'tuesday' | 'wednesday' | 'thursday' | 'friday' | 'saturday' | 'sunday';

export enum WeekDayEnum {
  monday = 'lundi',
  tuesday = 'mardi',
  wednesday = 'mercredi',
  thursday = 'jeudi',
  friday = 'vendredi',
  saturday = 'samedi',
  sunday = 'dimanche',
}

export class Time {
  opening: string;
  closing: string;

  constructor(obj?: { opening: string; closing: string }) {
    Object.assign(this, obj);
  }

  public formatOpeningDate(): string {
    return this.formatDate(this.opening);
  }

  public formatClosingDate(): string {
    return this.formatDate(this.closing);
  }

  private formatDate(n: string): string {
    return n.replace(':', 'h');
  }
}

export class Day {
  open = false;
  /**
   * A day can have two opening times
   * @example 10:00 - 12:00 & 16:00 - 18:00
   */
  time: Time[];

  constructor(obj?: Day) {
    Object.assign(this, obj, {
      time: obj?.time ? obj.time.map((time) => new Time(time)) : [],
    });
  }
}

export class Week {
  monday: Day;
  tuesday: Day;
  wednesday: Day;
  thursday: Day;
  friday: Day;
  saturday: Day;
  sunday: Day;

  constructor(obj?: Week) {
    Object.assign(this, obj, {
      monday: obj?.monday ? new Day(obj.monday) : new Day(),
      tuesday: obj?.tuesday ? new Day(obj.tuesday) : new Day(),
      wednesday: obj?.wednesday ? new Day(obj.wednesday) : new Day(),
      thursday: obj?.thursday ? new Day(obj.thursday) : new Day(),
      friday: obj?.friday ? new Day(obj.friday) : new Day(),
      saturday: obj?.saturday ? new Day(obj.saturday) : new Day(),
      sunday: obj?.sunday ? new Day(obj.sunday) : new Day(),
    });
  }

  /**
   * When iterating over Days in a week, override the default "keyvalue" pipe which gives incorrect typing.
   * @example
   * for (let day of structure.hours)...
   * -> day.key = tuesday
   * -> day.value = {open: true, time: [...]}
   * @yields day of the week
   */
  *[Symbol.iterator](): Generator<{ key: dayType; value: Day }> {
    yield { key: 'monday', value: this.monday };
    yield { key: 'tuesday', value: this.tuesday };
    yield { key: 'wednesday', value: this.wednesday };
    yield { key: 'thursday', value: this.thursday };
    yield { key: 'friday', value: this.friday };
    yield { key: 'saturday', value: this.saturday };
    yield { key: 'sunday', value: this.sunday };
  }

  public hasData(): boolean {
    if (
      this.monday.time.length === 0 &&
      this.tuesday.time.length === 0 &&
      this.wednesday.time.length === 0 &&
      this.thursday.time.length === 0 &&
      this.friday.time.length === 0 &&
      this.saturday.time.length === 0 &&
      this.sunday.time.length === 0
    ) {
      return false;
    }
    return true;
  }
}
