import { Component, ElementRef, OnInit, Renderer2, ViewEncapsulation } from '@angular/core';
import { DomSanitizer, Meta } from '@angular/platform-browser';
import { ActivatedRoute } from '@angular/router';
import packageJson from '../../../package.json';
import { Page } from './models/page.model';
import { PageService } from './services/page.service';

enum PageEnum {
  quiSommesNous = 'qui-sommes-nous',
  accessibilite = 'accessibilite',
}

@Component({
  selector: 'app-page',
  templateUrl: './page.component.html',
  styleUrls: ['./page.component.scss', '../../assets/ghost/cards.min.css'],
  encapsulation: ViewEncapsulation.None,
})
export class PageComponent implements OnInit {
  public page: Page;
  public version: string;
  private slugPage: string;

  constructor(
    private sanitizer: DomSanitizer,
    private route: ActivatedRoute,
    private pageService: PageService,
    private meta: Meta,
    private readonly elementRef: ElementRef,
    private renderer: Renderer2,
  ) {}

  ngOnInit(): void {
    // add ghost JS
    const script = this.renderer.createElement('script');
    script.src = '/assets/ghost/cards.min.js';
    this.renderer.appendChild(this.elementRef.nativeElement, script);

    this.route.params.subscribe((routeParams) => {
      this.slugPage = routeParams.slugPage;
      this.pageService.getPage(this.slugPage).subscribe((page) => {
        this.page = page.pages[0];
        this.page.safeHtml = this.sanitizer.bypassSecurityTrustHtml(this.page.html);
        this.meta.updateTag({
          name: 'description',
          content: this.page.meta_description,
        });
      });
      // Display version number in 'About' page only
      this.version = this.slugPage === PageEnum.quiSommesNous ? packageJson.version : '';
    });
  }
}
