import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { TagEnum } from '../../enum/tag.enum';
import { Tag } from '../../models/tag.model';
import { TagWithMeta } from '../../models/tagWithMeta.model';
import { parseSlugToTag } from '../utils/NewsUtils';
@Component({
  selector: 'app-post-header',
  templateUrl: './post-header.component.html',
  styleUrls: ['./post-header.component.scss'],
})
export class PostHeaderComponent implements OnInit {
  public tags: TagWithMeta;
  public tagEnum = TagEnum;
  public currentTab = 0;

  public checkedPublicTags: Tag[] = [];
  public checkedLocationTags: Tag[] = [];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
  ) {}

  ngOnInit(): void {
    this.route.data.subscribe((data) => {
      if (data.tags) {
        this.tags = data.tags;
        this.removeTagBySlug(TagEnum.aLaUneSection);
        this.updateTagName(TagEnum.aLaUne, 'Les plus récentes');
        this.sortTagsByName(this.tags.commune);
      }
    });

    this.route.queryParams.subscribe((queryParams) => {
      // We navigateTo distinct routes, so we need to recover the currentTab after rerouting
      if (queryParams.mainTag) {
        this.currentTab = this.tags.others.findIndex((tag) => tag.slug === queryParams.mainTag);
      }
      if (queryParams.publicTags) {
        this.checkedPublicTags = parseSlugToTag(queryParams.publicTags);
      }
      if (queryParams.locationTags) {
        this.checkedLocationTags = parseSlugToTag(queryParams.locationTags);
      }
    });
  }

  public getTabsNames(): string[] {
    return this.tags.others.map((tab) => tab.name);
  }

  private removeTagBySlug(slugToRemove: string): void {
    this.tags.others = this.tags.others.filter((tag) => tag.slug !== slugToRemove);
  }

  private updateTagName(slugToUpdate: string, newName: string): void {
    this.tags.others.forEach((tag) => {
      if (tag.slug === slugToUpdate) {
        tag.name = newName;
      }
    });
  }

  private sortTagsByName(tags: Tag[]): void {
    tags.sort((tagA, tagB) => this.sortArray(tagA, tagB));
  }

  private sortArray(tagA: Tag, tagB: Tag): number {
    const nameTagA = tagA.name.toUpperCase();
    const nameTagB = tagB.name.toUpperCase();
    return nameTagA.localeCompare(nameTagB);
  }

  public activateTag(tabIndex: number): void {
    this.router.navigate(['/actualites'], {
      relativeTo: this.route,
      queryParams: {
        mainTag: this.getMainTag(this.tags.others[tabIndex]),
        publicTags: this.checkedPublicTags.map((tag) => tag.slug),
        locationTags: this.checkedLocationTags.map((tag) => tag.slug),
      },
      queryParamsHandling: 'merge',
    });
  }

  public getMainTag(tag: Tag): string {
    if (tag.slug === TagEnum.aLaUne) {
      return '';
    }
    return tag.slug === this.tagEnum.etudes ? tag.name : tag.slug;
  }
}
