import { Component, Input, OnInit } from '@angular/core';
import { NewsletterService } from '../../services/newsletter.service';
import { NotificationService } from '../../services/notification.service';

@Component({
  selector: 'app-profile-newsletter',
  templateUrl: './profile-newsletter.component.html',
})
export class ProfileNewsletterComponent implements OnInit {
  @Input() public userEmail: string;
  public isChecked = false;
  public label = '';
  public isLoading = true;

  constructor(
    private newsletterService: NewsletterService,
    private notificationService: NotificationService,
  ) {}

  ngOnInit(): void {
    this.newsletterService.find(this.userEmail).subscribe({
      next: (result) => {
        this.isChecked = result !== null;
        this.setLabel();
        this.isLoading = false;
      },
    });
  }

  public setLabel(): void {
    this.label = this.isChecked
      ? "Vous êtes abonné·e à la newsletter Rés'in"
      : "Vous n’êtes pas encore abonné·e à la newsletter Rés'in";
  }

  public handleClick(value: boolean): void {
    this.isChecked = value;
    if (value) {
      this.handleSubscribe();
    } else {
      this.handleUnsubscribe();
    }
  }

  private handleSubscribe(): void {
    this.isLoading = true;
    this.newsletterService.subscribe(this.userEmail).subscribe({
      next: (result) => {
        this.setLabel();
        this.notificationService.showSuccess(`L'email ${result.email} a bien été ajouté à la newsletter`);
        this.isLoading = false;
      },
      error: (error) => {
        if (error.status === 418) {
          this.notificationService.showError(
            "Merci de vérifier l'email que vous souhaitez inscrire",
            `L'email ${this.userEmail} semble factice ou invalide`,
          );
        } else {
          this.notificationService.showErrorPleaseRetry(
            `L'email ${this.userEmail} n'a pas pu être ajouté à la newsletter`,
          );
        }
        this.isChecked = false;
        this.isLoading = false;
      },
    });
  }

  private handleUnsubscribe(): void {
    this.isLoading = true;
    this.newsletterService.unsubscribe(this.userEmail).subscribe({
      next: (result) => {
        this.setLabel();
        this.notificationService.showSuccess(`L'email ${result.email} a bien été retiré de la newsletter`);
        this.isLoading = false;
      },
      error: (error) => {
        if (error.status === 404) {
          this.notificationService.showError(
            "Merci de vérifier l'email que vous souhaitez désinscrire",
            `L'email ${this.userEmail} n'est pas inscrit à la newsletter`,
          );
        } else {
          this.notificationService.showErrorPleaseRetry(
            `L'email ${this.userEmail} n'a pas pu être retiré de la newsletter`,
          );
        }
        this.isChecked = true;
        this.isLoading = false;
      },
    });
  }
}
