import { NgModule } from '@angular/core';
import { Route, RouterModule, Routes } from '@angular/router';
import { FooterComponent } from '../footer/footer.component';
import { AuthGuard } from '../guards/auth.guard';
import { DeactivateGuard } from '../guards/deactivate.guard';
import { IsPersonalOfferOwnerGuard } from '../guards/isPersonalOfferOwner.guard';
import { RoleGuard } from '../guards/role.guard';
import { PersonalOfferResolver } from '../resolvers/personal-offer.resolver';
import { StructureResolver } from '../resolvers/structure.resolver';
import { RouteRole } from '../shared/enum/routeRole.enum';
import { EditComponent } from './edit/edit.component';
import { PersonalOfferEditionComponent } from './personal-offer-edition/personal-offer-edition.component';
import { ProfileComponent } from './profile.component';
import { StructureEditionSummaryComponent } from './structure-edition-summary/structure-edition-summary.component';
import { StructureMembersManagementComponent } from './structure-members-management/structure-members-management.component';
import { StructuresManagementComponent } from './structures-management/structures-management.component';

const footerOutletRoute: Route = {
  path: '',
  outlet: 'footer',
  component: FooterComponent,
};

const routes: Routes = [
  {
    path: 'edition',
    canActivate: [AuthGuard],
    canDeactivate: [DeactivateGuard],
    component: EditComponent,
  },
  {
    path: 'gestion-structures',
    component: StructuresManagementComponent,
  },
  footerOutletRoute,
  {
    path: '',
    children: [
      {
        path: '',
        component: ProfileComponent,
      },
      {
        path: ':userPermalink',
        component: ProfileComponent,
      },
    ],
  },
  {
    path: 'edition-structure/:permalink',
    component: StructureEditionSummaryComponent,
    canActivate: [RoleGuard],
    canDeactivate: [DeactivateGuard],
    data: { allowedRoles: [RouteRole.structureAdmin] },
    resolve: {
      structure: StructureResolver,
    },
  },
  {
    path: 'edition-offre-personnelle/:id',
    component: PersonalOfferEditionComponent,
    canActivate: [IsPersonalOfferOwnerGuard],
    resolve: {
      personalOffer: PersonalOfferResolver,
    },
  },
  {
    path: 'gestion-membres/:permalink',
    component: StructureMembersManagementComponent,
    canActivate: [RoleGuard],
    data: { allowedRoles: [RouteRole.structureAdmin] },
    resolve: {
      structure: StructureResolver,
    },
  },
];
@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class ProfileRoutingModule {}
