import { Component, EventEmitter, Input, Output } from '@angular/core';
import { lastValueFrom } from 'rxjs';
import { StructureWithOwners } from '../../models/structureWithOwners.model';
import { TempUser } from '../../models/temp-user.model';
import { NotificationService } from '../../services/notification.service';
import { StructureService } from '../../services/structure.service';
import { CustomRegExp } from '../../utils/CustomRegExp';

@Component({
  selector: 'app-structure-add-member-modal',
  templateUrl: './structure-add-member-modal.component.html',
})
export class StructureAddMemberModalComponent {
  @Input() public opened: boolean;
  @Input() public structure: StructureWithOwners;
  @Output() closed = new EventEmitter<boolean>();
  public email = '';

  constructor(
    private structureService: StructureService,
    private notificationService: NotificationService,
  ) {}

  public async closeModal(memberAddRequested: boolean): Promise<void> {
    if (memberAddRequested) {
      await this.addOwner();
    }
    this.closed.emit(memberAddRequested);
  }

  public emailValid(): boolean {
    return CustomRegExp.EMAIL.test(this.email);
  }

  public getEmailStatus(): 'success' | 'error' {
    if (this.email === '') return null;
    return this.emailValid() ? 'success' : 'error';
  }

  public async addOwner(): Promise<void> {
    // stop here if form is invalid
    if (!this.emailValid()) {
      return;
    }
    const user = new TempUser();
    user.email = this.email.toLowerCase();

    try {
      const res = await lastValueFrom(this.structureService.addOwnerToStructure(user, this.structure.structure._id));
      if ((res as TempUser).email) {
        this.notificationService.showSuccess("La demande d'ajout a bien été effectuée");
      } else {
        this.notificationService.showSuccess('Le membre a bien été ajouté');
      }
      this.email = '';
    } catch (e) {
      if (e.status === 422) {
        this.notificationService.showError('', `L'email ${user.email} est déjà rattaché à la structure`);
      } else {
        this.notificationService.showErrorPleaseRetry("Le membre n'a pas pu être ajouté");
      }
    }
  }
}
