import { Component, OnInit, Input } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ProfileService } from '../profile/services/profile.service';
import { AuthService } from '../services/auth.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-reset-email',
  templateUrl: './reset-email.component.html',
  styleUrls: ['./reset-email.component.scss'],
})
export class ResetEmailComponent implements OnInit {
  @Input() statusCode: number;
  public token: string;
  public changeSuccess = false;

  constructor(
    private activatedRoute: ActivatedRoute,
    private profileService: ProfileService,
    private authService: AuthService,
    private router: Router,
  ) {
    this.token = this.activatedRoute.snapshot.paramMap.get('id');
  }

  ngOnInit(): void {
    if (this.token) {
      this.changeEmail();
    }
  }

  public goToContact(): void {
    this.router.navigate(['/contact']);
  }

  private changeEmail(): void {
    this.profileService.verifyAndUpdateEmail(this.token).subscribe(
      () => {
        this.changeSuccess = true;

        setTimeout(() => {
          this.authService.logout();
        }, 10000); // Wait for 10 seconds
      },
      () => {
        this.changeSuccess = false;
      },
    );
  }
}
