import { Component, OnInit } from '@angular/core';
import { AbstractControl, FormControl, FormGroup, Validators } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import { AuthService } from '../services/auth.service';
import { NotificationService } from '../services/notification.service';
import { CustomRegExp } from '../utils/CustomRegExp';

@Component({
  selector: 'app-reset-password',
  templateUrl: './forgot-password.component.html',
  styleUrls: ['./reset-password.component.scss'],
})
export class ForgotPasswordComponent implements OnInit {
  public forgotPasswordForm = new FormGroup({
    email: new FormControl('', [Validators.required, Validators.pattern(CustomRegExp.EMAIL)]),
  });
  public loading = false;
  public token: string;

  constructor(
    private authService: AuthService,
    private router: Router,
    private notificationService: NotificationService,
    private activatedRoute: ActivatedRoute,
  ) {}

  ngOnInit(): void {
    this.activatedRoute.queryParams.subscribe((params) => {
      this.token = params.token;
    });
  }

  /** Getter for email control */
  get email(): AbstractControl<string, string> {
    return this.forgotPasswordForm.get('email');
  }

  public onSubmit(): void {
    // stop here if form is invalid
    if (this.forgotPasswordForm.invalid) return;

    this.loading = true;
    this.authService.resetPassword(this.email.value).subscribe({
      next: () => {
        this.notificationService.showSuccess(
          'Un mail de confirmation de modification de votre mot de passe vous a été envoyé.',
        );
        this.goLogin();
      },
      complete: () => {
        this.loading = false;
      },
    });
  }

  public goLogin(): void {
    this.router.navigateByUrl('/connexion');
  }
}
