import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { PersonalOffer } from '../models/personalOffer.model';
import { Category } from '../structure-list/models/category.model';

@Injectable({
  providedIn: 'root',
})
export class PersonalOfferService {
  private readonly baseUrl = 'api/personal-offers';
  constructor(private http: HttpClient) {}

  public createPersonalOffer(structureId: string, personalOffer: PersonalOffer): Observable<PersonalOffer> {
    return this.http.post<PersonalOffer>(this.baseUrl, { structureId, personalOffer });
  }

  public getPersonalOffer(id: string): Observable<PersonalOffer> {
    return this.http.get<PersonalOffer>(`${this.baseUrl}/${id}`);
  }

  public updatePersonalOffer(id: string, categories: Category[]): Observable<PersonalOffer> {
    return this.http.put<PersonalOffer>(`${this.baseUrl}/${id}`, {
      categories,
    });
  }

  public deletePersonalOffer(id: string): Observable<PersonalOffer> {
    return this.http.delete<PersonalOffer>(`${this.baseUrl}/${id}`);
  }
}
