import { Component, ElementRef, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { SpriteFolderType } from '../svg-icon/SpriteFolder.type';

/** values will be used for css selectors */
export type ButtonType =
  | 'primary'
  | 'primaryBlack'
  | 'primaryWarning'
  | 'primarySuccess'
  | 'secondary'
  | 'secondarySuccess'
  | 'secondaryDelete'
  | 'tertiary';

@Component({
  selector: 'app-button',
  templateUrl: './button.component.html',
  styleUrls: ['./button.component.scss'],
})
export class ButtonComponent {
  /** Button label */
  @Input({ required: true }) label: string;

  /** HTML type of the button */
  @Input() type: 'submit' | 'button' | 'reset' = 'button';

  /** What variant should be the button ? */
  @Input({ required: true }) variant: ButtonType;

  /** Affects the height of the button */
  @Input() size?: 'small' | 'medium' | 'large' = 'medium';

  /** Should the button be wide ? (250px) */
  @Input() wide = false;

  /** Should the button be disabled ? */
  @Input() disabled = false;

  /** Sets the position of the icon if one provided */
  @Input() iconPosition: 'left' | 'right' = 'left';

  /** Folder of the icon ex: assets/ico */
  @Input() iconFolder: SpriteFolderType = 'ico';

  /** Icon name */
  @Input() iconName?: string;

  /** Icon color, defaults to none as the svg-icon does */
  @Input() iconColor = 'none';

  /** Button aria-label */
  @Input() ariaLabel?: string = null;

  /** Click handler */
  @Output() action = new EventEmitter<Event>();

  @ViewChild('buttonElement') buttonElement!: ElementRef;

  public get classes(): string[] {
    return [this.variant, this.size, this.wide ? 'wide' : ''];
  }

  public focus(): void {
    this.buttonElement.nativeElement.focus();
  }
}
