import { AfterContentInit, Component, ContentChild, Input } from '@angular/core';
import { CollapseContentComponent } from './collapse-content/collapse-content.component';
import { CollapseHeaderComponent } from './collapse-header/collapse-header.component';
import { CollapseType } from './collapse.type';

@Component({
  selector: 'app-collapse',
  template: `<div class="collapse" [ngClass]="classes">
    <ng-content />
  </div>`,
  styleUrls: ['collapse.component.scss'],
})
export class CollapseComponent implements AfterContentInit {
  @ContentChild(CollapseHeaderComponent) title: CollapseHeaderComponent;
  @ContentChild(CollapseContentComponent) content: CollapseContentComponent;

  @Input() variant?: CollapseType = CollapseType.Regular;

  /** Adapts border-radius and right padding */
  @Input() size?: 'small' | 'medium' = 'small';

  /** Box-shadow when expanded? */
  @Input() boxShadow? = false;

  @Input() warningBorder? = false;

  /** Default expanded value */
  @Input() expanded? = false;

  ngAfterContentInit(): void {
    this.title.size = this.size;
    this.title.expanded = this.expanded;
    this.content.expanded = this.expanded;
    this.title.toggle.subscribe(() => this.toggle());
  }

  private toggle(): void {
    this.expanded = !this.expanded;
    this.title.expanded = this.expanded;
    this.content.expanded = this.expanded;
  }

  public get classes(): string[] {
    return [
      this.variant,
      this.size,
      this.expanded ? 'expanded' : '',
      this.boxShadow ? 'boxShadow' : '',
      this.warningBorder ? 'warningBorder' : '',
    ];
  }
}
