import { CommonModule } from '@angular/common';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import type { Meta, StoryObj } from '@storybook/angular';
import { moduleMetadata } from '@storybook/angular';
import { SvgIconComponent } from '../svg-icon/svg-icon.component';
import { CollapseContentComponent } from './collapse-content/collapse-content.component';
import { CollapseHeaderComponent } from './collapse-header/collapse-header.component';
import { CollapseComponent } from './collapse.component';

// More on how to set up stories at: https://storybook.js.org/docs/angular/writing-stories/introduction
const meta: Meta<CollapseComponent> = {
  title: 'Components/Collapse',
  component: CollapseComponent,
  tags: ['autodocs'],
  decorators: [
    moduleMetadata({
      declarations: [SvgIconComponent, CollapseHeaderComponent, CollapseContentComponent],
      imports: [CommonModule, BrowserAnimationsModule],
    }),
  ],
  argTypes: {},
};

export default meta;
type Story = StoryObj<CollapseComponent>;

const collapseChildren = `
    <app-collapse-header>
      <div style="padding:0.5rem;">
      <p style="margin:0;">Contenu de l'en-tête</p>
      </div>
    </app-collapse-header>
    <app-collapse-content>
      <div style="padding:0.5rem;border-top:1px solid #e9e9e9;">
        <p>Premier élément</p>
        <p>Deuxième élément</p>
        <p>Troisième élément</p>
        <p>Quatrième élément</p>
      </div>
    </app-collapse-content>
`;

export const CollapseSmall: Story = {
  render: () => ({
    template: `
      <app-collapse>
        ${collapseChildren}
      </app-collapse>`,
  }),
};

export const CollapseSmallExpanded: Story = {
  render: () => ({
    template: `
      <app-collapse [expanded]="true">
        ${collapseChildren}
      </app-collapse>`,
  }),
};

export const CollapseMedium: Story = {
  render: () => ({
    template: `
      <app-collapse [size]="'medium'">
        ${collapseChildren}
      </app-collapse>`,
  }),
};

export const CollapseMediumBoxShadow: Story = {
  render: () => ({
    template: `
      <app-collapse [size]="'medium'" [boxShadow]="true">
        ${collapseChildren}
      </app-collapse>`,
  }),
};

export const CollapseMediumWarning: Story = {
  render: () => ({
    template: `
      <app-collapse [size]="'medium'" [variant]="'collapse-warning'">
        ${collapseChildren}
      </app-collapse>`,
  }),
};
