import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { Router } from '@angular/router';
import { get } from 'lodash';
import { Owner } from '../../../models/owner.model';
import { User, UserAnnuary } from '../../../models/user.model';
import { WindowScrollService } from '../../service/windowScroll.service';

@Component({
  selector: 'app-member-card',
  templateUrl: './member-card.component.html',
  styleUrls: ['./member-card.component.scss'],
})
export class MemberCardComponent implements OnInit {
  /** The user info to display */
  @Input({ required: true }) public member: User | Owner | UserAnnuary;

  /** If true, shows the RDV icon if available */
  @Input() public showAppointment = false;

  /** If true, shows the contact info (phone + email), if provided */
  @Input() public showContactInfo = true;

  /** If true, shows the employer */
  @Input() public showEmployer = true;

  /** If true, click event redirects to profile */
  @Input() public redirectToProfile = true;

  /** If true, shows a radio button to select the card, disables the redirection to profile */
  @Input() public showRadioButton = false;

  /** If true, checks the radioButton */
  @Input() public isChecked = false;

  @Output() public selectedCard = new EventEmitter<string>();

  constructor(
    private router: Router,
    private windowScrollService: WindowScrollService,
  ) {}

  ngOnInit(): void {
    if (this.showRadioButton && this.redirectToProfile) {
      console.warn("Can't make a card redirect to a profile with a radio button.");
      this.redirectToProfile = false;
    }
  }

  isInteractive(): boolean {
    return this.showRadioButton || this.redirectToProfile;
  }

  getJob(): string {
    return this.member.job?.name ?? '';
  }

  /** Depending on User or Owner return the phone number of false */
  getPhone(): string | false {
    return get(this.member, 'phone') ?? false;
  }

  /** Depending on User or UserAnnuary return the email of false */
  getEmail(): string | false {
    return get(this.member, 'email') ?? false;
  }

  cardClicked(): void {
    if (this.redirectToProfile) {
      this.windowScrollService.scrollYToPreserve.next(this.windowScrollService.scrollY.value);
      this.router.navigateByUrl(`/profil/${this.member.permalink}`);
    } else if (this.showRadioButton) {
      this.selectedCard.emit(this.member._id);
    }
  }
}
