import { CommonModule } from '@angular/common';
import type { Meta, StoryObj } from '@storybook/angular';
import { moduleMetadata } from '@storybook/angular';
import { ButtonComponent } from '../button/button.component';
import { SvgIconComponent } from '../svg-icon/svg-icon.component';
import { ModalComponent } from './modal.component';

// More on how to set up stories at: https://storybook.js.org/docs/angular/writing-stories/introduction
const meta: Meta<ModalComponent> = {
  title: 'Components/Modal',
  component: ModalComponent,
  tags: ['autodocs'],
  decorators: [
    moduleMetadata({
      declarations: [SvgIconComponent, ButtonComponent],
      imports: [CommonModule],
    }),
  ],
  argTypes: {},
};

export default meta;
type Story = StoryObj<ModalComponent>;

export const SingleButton: Story = {
  args: {
    opened: true,
    title: 'Title',
    content: 'Test text',
    validateLabel: 'Valider',
    cancelLabel: 'Annuler',
    singleButton: true,
  },
  render: (args) => ({
    template: `<app-modal [opened]="${args.opened}"
    [validateLabel]="'${args.validateLabel}'"
    [cancelLabel]="'${args.cancelLabel}'"
    [title]="'${args.title}'"
    [singleButton]="${args.singleButton}"
    >
    ${args.content}
    </app-modal>`,
  }),
};

export const TwoButtons: Story = {
  args: {
    ...SingleButton.args,
    singleButton: false,
  },
  render: SingleButton.render,
};

export const FormattedMessage: Story = {
  args: {
    ...SingleButton.args,
    singleButton: false,
    title: 'Travaillez-vous ici&nbsp;?',
    content: `
    <div class="modalContent">
      Un message sera envoyé aux membres de la structure : <br />
      <span class="emphasized">Le Son du Clic</span>
    </div>`,
  },
  render: SingleButton.render,
};

export const WithImage: Story = {
  args: {
    ...SingleButton.args,
    content: `<div>
        <img src="../../../../../assets/img/resin-login.svg" alt="" />
        <h3>Additional text</h3>
      </div>`,
  },
  render: SingleButton.render,
};
