import { Component, Input, OnInit } from '@angular/core';
import { Structure } from '../../../models/structure.model';

@Component({
  selector: 'app-print-structures-grid',
  templateUrl: './print-structures-grid.component.html',
  styleUrls: ['./print-structures-grid.component.scss'],
})
export class PrintStructuresGridComponent implements OnInit {
  @Input({ required: true }) structures: Structure[];
  public structuresByCommunePairs: Record<string, Structure[][]>;

  ngOnInit(): void {
    this.structuresByCommunePairs = this.structures.reduce((communes, structure) => {
      const communePairs: Structure[][] = communes[structure.address.commune] || [];

      if (communePairs.length === 0 || communePairs[communePairs.length - 1].length === 2) {
        communePairs.push([structure]);
      } else {
        communePairs[communePairs.length - 1].push(structure);
      }

      communes[structure.address.commune] = communePairs;
      return communes;
    }, {});
  }

  getServices(structure: Structure): string[] {
    const services: string[] = [];
    if (structure.hasFreeOnlineHelp()) {
      services.push('Aide gratuite aux démarches en ligne');
    }
    if (structure.hasFreeWorkshops()) {
      services.push('Accompagnement gratuit aux usages numériques');
    } else {
      services.push('Formations payantes aux usages numériques');
    }
    if (structure.hasSolidarityMaterial()) {
      services.push('Matériel à tarif solidaire');
    }
    if (structure.hasEquipments()) {
      services.push('Matériel en accès libre');
    }
    return services;
  }
}
