import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';

@Component({
  selector: 'app-select-or-create',
  templateUrl: './select-or-create.component.html',
  styleUrls: ['./select-or-create.component.scss'],
})
export class SelectOrCreateComponent implements OnInit {
  @Input() public name: string;
  @Input() public value: string;
  @Input() public isFeminineWord?: boolean;
  @Input() private autocompleteFunction: Function;

  @Output() selectItem = new EventEmitter<any>();
  @Output() valueChange = new EventEmitter<any>();
  @Output() createValueChange = new EventEmitter<any>();

  public data = [];
  public isAlreadySearching = false;
  public searchString: string;
  public isAddingNewItem = false;
  public isSelectedItem = false;
  public createValue: string;

  ngOnInit(): void {
    if (this.value) {
      this.isSelectedItem = true;
    }
  }

  public onAutocompleteValueChange(value: string): void {
    this.isSelectedItem = false;
    this.selectItem.emit(null);
    this.searchString = value;
    if (!this.isAlreadySearching) {
      this.isAlreadySearching = true;
      this.autocompleteFunction(value).subscribe((data) => {
        this.data = data;
        this.isAlreadySearching = false;

        // If user typed another string meanwhile, relaunch the search for this new string
        if (this.searchString !== value) {
          this.onAutocompleteValueChange(this.searchString);
        }
      });
    }
    this.valueChange.emit(value);
  }

  public onCreateValueChange(value: string): void {
    this.createValue = value;
    this.createValueChange.emit(value);
  }

  public toggleAddItem(): void {
    this.isAddingNewItem = !this.isAddingNewItem;
  }

  public selectResult(hit: any): void {
    this.isSelectedItem = true;
    // Set input value
    this.searchString = hit.name;
    // Reset autocomplete
    this.data = [];
    // Emit chosen value
    this.selectItem.emit(hit);
  }

  public isFieldValid(): boolean {
    return this.createValue && this.createValue !== '';
  }
}
