import { Component, EventEmitter, Input, Output } from '@angular/core';
import { SpriteFolderType } from '../svg-icon/SpriteFolder.type';

@Component({
  selector: 'app-tag-item',
  templateUrl: './tag-item.component.html',
  styleUrls: ['./tag-item.component.scss'],
})
export class TagItemComponent {
  /** Tag label */
  @Input({ required: true }) label: string;

  /** How large should be the button ? */
  @Input() size?: 'small' | 'medium' = 'medium';

  /** What color should the tag be ? */
  @Input() color?: 'white' | 'black' | 'red' | 'blue' | 'grey' | 'green' = 'white';

  /** Should the button be clickable ? */
  @Input() clickable = false;

  /** Should the button be disabled */
  @Input() disabled = false;

  /** Sets the position of the icon if one provided */
  @Input() iconPosition?: 'left' | 'right' = 'left';

  /** Folder of the icon ex: assets/ico */
  @Input() iconFolder: SpriteFolderType = 'ico';

  /** Icon name */
  @Input() iconName?: string;

  /** Button aria-label */
  @Input() ariaLabel?: string = null;

  /** Click handler */
  @Output() action = new EventEmitter<Event>();

  public get classes(): string[] {
    return [this.size, this.color, this.clickable ? 'clickable' : 'unclickable'];
  }

  public get iconSize(): 'icon-12' | 'icon-16' {
    return this.size === 'small' ? 'icon-12' : 'icon-16';
  }
}
