import { CommonModule } from '@angular/common';
import type { Meta, StoryObj } from '@storybook/angular';
import { moduleMetadata } from '@storybook/angular';
import { SvgIconComponent } from '../svg-icon/svg-icon.component';
import { TagItemComponent } from './tag-item.component';

// More on how to set up stories at: https://storybook.js.org/docs/angular/writing-stories/introduction
const meta: Meta<TagItemComponent> = {
  title: 'Components/Tag item',
  component: TagItemComponent,
  tags: ['autodocs'],
  decorators: [
    moduleMetadata({
      declarations: [SvgIconComponent],
      imports: [CommonModule],
    }),
  ],
  argTypes: {},
};

export default meta;
type Story = StoryObj<TagItemComponent>;

export const Small: Story = {
  args: {
    label: 'Label tag',
    size: 'small',
    clickable: true,
  },
};

export const SmallWithIcon: Story = {
  args: {
    ...Small.args,
    iconFolder: 'ico',
    iconName: 'email',
  },
};

export const Medium: Story = {
  args: {
    label: 'Medium tag',
    color: 'white',
    size: 'medium',
    clickable: true,
  },
};

export const MediumSelected: Story = {
  args: {
    label: 'Medium tag',
    color: 'black',
    size: 'medium',
    iconFolder: 'ico',
    iconName: 'mail',
  },
};

export const MediumRed: Story = {
  args: {
    label: 'Médiathèque/Bibliothèque',
    color: 'red',
    size: 'medium',
    clickable: false,
  },
};

export const MediumBlack: Story = {
  args: {
    label: 'Médiathèque/Bibliothèque',
    color: 'black',
    size: 'medium',
    clickable: false,
  },
};

export const MediumGrey: Story = {
  args: {
    label: 'Médiathèque/Bibliothèque',
    color: 'grey',
    size: 'medium',
    clickable: true,
  },
};

export const MediumWithIcon: Story = {
  args: {
    ...Medium.args,
    iconFolder: 'ico',
    iconName: 'email',
  },
};

export const Unclickable: Story = {
  args: {
    label: 'Unclickable tag',
    clickable: false,
  },
};

export const MultipleTags: Story = {
  render: (args) => ({
    props: args,
    template: `
    <div class="tagList">
      <app-tag-item label="test 1" />
      <app-tag-item label="test 2" />
      <app-tag-item label="test 3" />
    </div>`,
  }),
};

export const OnOffTag: Story = {
  render: (args) => ({
    props: args,
    template: `
    <div class="tagList">
      <app-tag-item label="Option 1" iconName="tag-unchecked" color="white" [clickable]="true"/>
      <app-tag-item label="Option 2" iconName="tag-checked" color="green" [clickable]="true"/>
    </div>`,
  }),
};
