import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { firstValueFrom } from 'rxjs';
import { Structure } from '../../../models/structure.model';
import { TclStopPoint } from '../../../models/tclStopPoint.model';
import { TclService } from '../../../services/tcl.service';

@Component({
  selector: 'app-tcl-stop-points',
  templateUrl: './tcl-stop-points.component.html',
  styleUrls: ['./tcl-stop-points.component.scss'],
})
export class TclStopPointsComponent implements OnInit {
  @Input({ required: true }) structure: Structure;
  @Output() emitHasTclInfo = new EventEmitter<boolean>();
  @Input() compact = false;

  public tclStops: TclStopPoint[];

  constructor(private tclService: TclService) {}

  ngOnInit(): void {
    firstValueFrom(this.tclService.getTclStopPointBycoord(this.structure.getLon(), this.structure.getLat())).then(
      (res) => {
        this.tclStops = res;
        this.emitHasTclInfo.emit(this.tclStops.length > 0);
      },
    );
  }

  public get iconClass(): string {
    return this.compact ? 'acces-icon-compact' : 'acces-icon';
  }

  public get classes(): string[] {
    return [this.compact ? 'compact' : ''];
  }
}
