import { Pipe, PipeTransform } from '@angular/core';

@Pipe({
  name: 'slugify',
})
export class SlugifyPipe implements PipeTransform {
  transform(value: string): string {
    if (!value) return '';

    // Remove accents
    const withoutAccents = value.normalize('NFD').replace(/[\u0300-\u036f]/g, '');

    // Use a regex to create the slug
    return withoutAccents
      .toLowerCase()
      .trim()
      .replace(/[^a-z0-9\s-]/g, '') // Remove special characters
      .replace(/[\s-]+/g, '-') // Replace spaces and multiple hyphens with a single hyphen
      .replace(/^-+/, '') // Trim hyphens from the start
      .replace(/-+$/, ''); // Trim hyphens from the end
  }
}
