import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Structure } from '../../../models/structure.model';
import { ProfileService } from '../../../profile/services/profile.service';

@Component({
  selector: 'app-card',
  templateUrl: './card.component.html',
  styleUrls: ['./card.component.scss'],
})
export class CardComponent implements OnInit {
  /** The structure element to display */
  @Input() public structure: Structure;

  /** If true, click event redirects to profile */
  @Input() public redirectToStructure = true;

  /** If true, shows a radio button to select the card, disables the redirection to structure */
  @Input() public showRadioButton = false;

  /** If true, checks the radioButton */
  @Input() public isChecked = false;

  /** If true, the form comes from the orientation */
  @Input() public isOrientation = false;
  /** If in orientation, when we add to list, the card becomes selected */
  @Input() public isSelected = false;
  /** If true, the form comes from the orientation and will propose to reserve an appointment */
  @Input() public isOrientationRdv = false;

  @Output() public showDetails = new EventEmitter<Structure>();
  @Output() public hover = new EventEmitter<Structure>();
  @Output() public addToList = new EventEmitter<Structure>();
  @Output() public selectRDV = new EventEmitter<Structure>();
  @Output() public selectedStructure = new EventEmitter<Structure>();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    public profileService: ProfileService,
  ) {}

  ngOnInit(): void {
    if (this.showRadioButton && this.redirectToStructure) {
      console.warn("Can't make a card redirect to a structure with a radio button.");
      this.redirectToStructure = false;
    }
  }

  isInteractive(): boolean {
    return this.showRadioButton || this.redirectToStructure || this.isOrientation;
  }

  /**
   * Display distance in m or km according to value
   */
  public formatDistance(): string {
    if (this.structure.distance > 1000) {
      return (this.structure.distance / 1000).toFixed(1).toString() + ' km';
    } else {
      return this.structure.distance + ' m';
    }
  }

  public cardClicked(): void {
    if (this.redirectToStructure) {
      this.showDetails.emit(this.structure);
      this.router.navigate([], {
        relativeTo: this.route,
        queryParams: {
          structure: this.structure.permalink,
        },
        state: { isOrientation: this.isOrientation },
      });
    } else {
      this.selectedStructure.emit(this.structure);
    }
  }

  public cardHover(): void {
    this.hover.emit(this.structure);
  }

  public cardAddToList(): void {
    this.addToList.emit(this.structure);
  }

  public cardRDV(): void {
    this.selectRDV.emit(this.structure);
  }
}
