import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { GeoJson } from '../map/models/geojson.model';
import { Structure } from '../models/structure.model';
import { AuthService } from '../services/auth.service';
import { PrintService } from '../shared/service/print.service';

@Component({
  selector: 'app-structure-list',
  templateUrl: './structure-list.component.html',
  styleUrls: ['./structure-list.component.scss'],
})
export class StructureListComponent implements OnChanges, OnInit {
  @Input() public isOrientation = false;
  @Input() public isOrientationRdv = false;
  @Input() public structureList: Structure[];
  @Input() public isLoading = true;
  @Input() public location: GeoJson;
  @Input() public selectedStructure: Structure = new Structure();
  @Input() public selectedStructureList: Structure[] = [];
  @Output() public displayMapMarkerId: EventEmitter<string> = new EventEmitter<string>();
  @Output() public selectedMarkerId: EventEmitter<string> = new EventEmitter<string>();
  @Output() public structureSelected: EventEmitter<Structure[]> = new EventEmitter<Structure[]>();
  @Output() public structureRDVSelected: EventEmitter<Structure> = new EventEmitter<Structure>();

  public structure: Structure;
  public printMode = false;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private authService: AuthService,
    private printService: PrintService,
  ) {
    this.route.data.subscribe((data) => {
      if (data.structure) {
        this.showDetails(new Structure(data.structure));
      } else {
        this.closeDetails();
      }
    });
  }

  ngOnInit(): void {
    if (this.printMode) {
      this.printService.onDataReady();
    }
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.selectedStructure && this.selectedStructure) {
      this.showDetails(this.selectedStructure);
      this.router.navigate([], {
        relativeTo: this.route,
        queryParams: {
          structure: this.selectedStructure.permalink,
        },
      });
    }
    if (changes.structureList) {
      document.getElementById('listCard').scrollTo(0, 0);
    }
  }

  public selectRDV(structure: Structure): void {
    this.structureRDVSelected.emit(structure);
  }

  public addToList(structure: Structure): void {
    const index = this.selectedStructureList.findIndex((elem) => elem._id === structure._id);
    if (index > -1) {
      this.selectedStructureList = this.selectedStructureList.filter((elem) => {
        return elem._id !== structure._id;
      });
    } else {
      this.selectedStructureList.push(structure);
    }
    this.selectedStructureList = this.selectedStructureList.slice();
    this.structureSelected.emit(this.selectedStructureList);
  }

  public isInPrintList(id: string): boolean {
    return this.selectedStructureList.findIndex((elem) => elem._id === id) > -1;
  }

  public addStructure(): void {
    if (!this.authService.isLoggedIn()) {
      this.router.navigateByUrl('/connexion');
    } else {
      this.router.navigateByUrl('/formulaire/structure');
    }
  }

  public showDetails(structure: Structure): void {
    this.structure = structure;
    this.selectedMarkerId.emit(this.structure._id);
  }

  public closeDetails(): void {
    this.selectedMarkerId.emit();
  }

  public handleCardHover(structure: Structure): void {
    this.displayMapMarkerId.emit(structure._id);
  }

  public mouseLeave(): void {
    this.displayMapMarkerId.emit(undefined);
  }

  public print(): void {
    this.printService.printDocuments('structures-search', this.structureList);
  }
}
