import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { formType } from '../../form/form-view/formType.enum';
import { structureFormStep } from '../../form/form-view/structure-form/structureFormStep.enum';
import { Structure } from '../../models/structure.model';
import { RouterListenerService } from '../../services/routerListener.service';
import { UserService } from '../../services/user.service';
import { JoinErrors } from '../enums/joinErrors.enum';
@Component({
  selector: 'app-structure-join',
  templateUrl: './structure-join.component.html',
  styleUrls: ['./structure-join.component.scss'],
})
export class StructureJoinComponent implements OnInit {
  public structureName = '';
  public isClaimed: boolean = null;
  public structureFormStepEnum = structureFormStep;
  public formTypeEnum = formType;
  public structure: Structure;
  public isStructureJoinValidated = null;
  public validationToken = null;
  public isLoading: boolean;
  public structureJoined: Structure;
  public newUserName: string;
  public errorStatus: number;
  public errorEnum = JoinErrors;

  constructor(
    private routerListener: RouterListenerService,
    private route: ActivatedRoute,
    private router: Router,
    private usersService: UserService,
  ) {}

  ngOnInit(): void {
    this.isClaimed = history.state.isClaimed;
    this.route.data.subscribe((data) => {
      if (data.structure) {
        this.structureName = data.structure.structureName;
        this.structure = data.structure;
      } else {
        this.isLoading = true;
      }
    });
    this.handleStructureJoin();
  }
  public handleStructureJoin(): void {
    this.route.queryParams.subscribe((params) => {
      this.isStructureJoinValidated = params.status;
      this.validationToken = params.token;
    });
    if (this.isStructureJoinValidated !== null && this.validationToken) {
      this.usersService.validateJoinStructure(this.validationToken, this.isStructureJoinValidated).subscribe({
        next: (res) => {
          this.structureJoined = res.structure;
          this.newUserName = res.username;
        },
        error: (err) => {
          this.errorStatus = err.status;
          console.error(err);
          this.isLoading = false;
        },
        complete: () => (this.isLoading = false),
      });
    }
  }

  public handleFinish(): void {
    this.routerListener.goToPreviousUrl();
  }
  public handleCallback(): void {
    if (this.structureJoined) {
      this.router.navigateByUrl(`/acteurs?structure=${this.structureJoined.permalink}`);
    }
    this.router.navigateByUrl(`/acteurs`);
  }
}
